package com.me.pacman.entity;

import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.math.Vector2;
import com.me.pacman.entity.ai.Target;
import com.me.pacman.state.LevelState;

public abstract class Entity {

    public LevelState state;
    public Vector2 pos;
    public int age;

    public Entity(LevelState state, float x, float y) {
        this.state = state;
        this.pos = new Vector2(x, y);
        this.age = 0;
    }

    public void render(SpriteBatch batch, int offsetX, int offsetY) {
        TextureRegion texture = getSprite();
        if (texture == null) {
            return;
        }
        batch.draw(texture, (int) (pos.x * 8) + (offsetX - 8), (pos.y * 8) + (offsetY - 8));
    }

    public boolean onSameTile(Entity other) {
        return (int) pos.x == (int) other.pos.x && (int) pos.y == (int) other.pos.y;
    }

    public Vector2 getTileVector() {
        return new Vector2((int) pos.x, (int) pos.y);
    }

    public Target getAsTarget() {
        return new Target(pos.x, pos.y);
    }

    public abstract TextureRegion getSprite();

    public void update(float dt) {
        this.age += 1;
    }

}
