package com.me.pacman.entity.path;

import com.badlogic.gdx.math.Vector2;
import com.me.pacman.entity.Direction;
import com.me.pacman.entity.MovableEntity;

import java.util.ArrayList;
import java.util.List;

public class Path {

    private float speed;            // speed in tiles/sec
    private float elapsed;          // seconds elapsed since beginning of path

    private List<Vector2> points;   // points in the path
    private List<Float> segmentLengths;
    private int pathSegments;       // total path segments

    private float pathLength;       // total path length
    private float progress;         // distance along path

    public Path(float speed, Vector2 start) {
        this.speed = speed;
        this.elapsed = 0;
        this.points = new ArrayList<>();
        this.segmentLengths = new ArrayList<>();
        addPoint(start);
    }

    public void addPoints(List<Vector2> points) {
        for (Vector2 point : points) {
            addPoint(point);
        }
    }

    protected void addPoint(Vector2 point) {
        points.add(point);

        if (points.size() == 1) {
            return;
        }

        pathSegments++;
        Vector2 previous = points.get(points.size()-2);
        float length = previous.dst(point);
        segmentLengths.add(length);
        pathLength += length;
    }

    public void updateEntity(MovableEntity entity) {
        if (finished()) {
            return;
        }

        float tmp = progress;
        for (int i = 0; i < pathSegments; i++) {
            float segmentLength = segmentLengths.get(i);

            if (tmp > segmentLength) {
                tmp -= segmentLength;
                continue;
            }

            Vector2 a = new Vector2(points.get(i));
            Vector2 b = new Vector2(points.get(i+1));

            Vector2 pathDir = b.sub(a).nor();

            entity.currDirection = Direction.fromVector(pathDir);
            entity.pos = a.add(pathDir.scl(tmp));
            break;
        }
    }

    public void reset() {
        elapsed = 0;
        progress = 0;
    }

    public boolean finished() {
        return progress >= pathLength;
    }

    public void update(float dt) {
        elapsed += dt;
        progress = elapsed * speed;
    }

}